import seaborn as sns

def get_test_dataset():
    """Temporary placeholder for test dataset, testing suite to be setup at a later date.

    Returns:
        dataframe: pandas dataframe
    """
    return sns.load_dataset('iris')